pub trait Sealed { }🔬This is a nightly-only experimental API. (
sealed)Expand description
This trait being unreachable from outside the crate prevents outside implementations of our extension traits. This allows adding more trait methods in the future.
Implementors
impl Sealed for i8
Allows extension traits within core.
impl Sealed for i16
Allows extension traits within core.
impl Sealed for i32
Allows extension traits within core.
impl Sealed for i64
Allows extension traits within core.
impl Sealed for i128
Allows extension traits within core.
impl Sealed for isize
Allows extension traits within core.
impl Sealed for u8
Allows extension traits within core.
impl Sealed for u16
Allows extension traits within core.
impl Sealed for u32
Allows extension traits within core.
impl Sealed for u64
Allows extension traits within core.
impl Sealed for u128
Allows extension traits within core.
impl Sealed for usize
Allows extension traits within core.